@@ -631,6 +631,8 @@ ev_job_render_run (EvJob *job)
 
 	ev_page = ev_document_get_page (job->document, job_render->page);
 	rc = ev_render_context_new (ev_page, job_render->rotation, job_render->scale);
+	ev_render_context_set_target_size (rc,
+					   job_render->target_width, job_render->target_height);
 	g_object_unref (ev_page);
 
 	job_render->surface = ev_document_render (job->document, rc);
@@ -838,7 +840,7 @@ ev_job_thumbnail_run (EvJob *job)
 {
 	EvJobThumbnail  *job_thumb = EV_JOB_THUMBNAIL (job);
 	EvRenderContext *rc;
-	GdkPixbuf       *pixbuf;
+	GdkPixbuf       *pixbuf = NULL;
 	EvPage          *page;
 
 	ev_debug_message (DEBUG_JOBS, "%d (%p)", job_thumb->page, job);
@@ -848,13 +850,19 @@ ev_job_thumbnail_run (EvJob *job)
 
 	page = ev_document_get_page (job->document, job_thumb->page);
 	rc = ev_render_context_new (page, job_thumb->rotation, job_thumb->scale);
+	ev_render_context_set_target_size (rc,
+					   job_thumb->target_width, job_thumb->target_height);
 	g_object_unref (page);
 
-	pixbuf = ev_document_get_thumbnail (job->document, rc);
+        if (job_thumb->format == EV_JOB_THUMBNAIL_PIXBUF)
+                pixbuf = ev_document_get_thumbnail (job->document, rc);
+        else
+                job_thumb->thumbnail_surface = ev_document_get_thumbnail_surface (job->document, rc);
 	g_object_unref (rc);
 	ev_document_doc_mutex_unlock ();
 
-        if (pixbuf) {
+        /* EV_JOB_THUMBNAIL_SURFACE is not compatible with has_frame = TRUE */
+        if (job_thumb->format == EV_JOB_THUMBNAIL_PIXBUF && pixbuf) {
                 job_thumb->thumbnail = job_thumb->has_frame ?
                         ev_document_misc_get_thumbnail_frame (-1, -1, pixbuf) : g_object_ref (pixbuf);
                 g_object_unref (pixbuf);
@@ -892,10 +900,29 @@ ev_job_thumbnail_new (EvDocument *document,
 	job->rotation = rotation;
 	job->scale = scale;
         job->has_frame = TRUE;
+        job->format = EV_JOB_THUMBNAIL_PIXBUF;
+        job->target_width = -1;
+        job->target_height = -1;
 
 	return EV_JOB (job);
 }
 
+EvJob *
+ev_job_thumbnail_new_with_target_size (EvDocument *document,
+                                       gint        page,
+                                       gint        rotation,
+                                       gint        target_width,
+                                       gint        target_height)
+{
+        EvJob *job = ev_job_thumbnail_new (document, page, rotation, 1.);
+        EvJobThumbnail  *job_thumb = EV_JOB_THUMBNAIL (job);
+
+        job_thumb->target_width = target_width;
+        job_thumb->target_height = target_height;
+
+        return job;
+}
+
 /**
  * ev_job_thumbnail_set_has_frame:
  * @job:
@@ -910,6 +937,22 @@ ev_job_thumbnail_set_has_frame (EvJobThumbnail  *job,
         job->has_frame = has_frame;
 }
 
+/**
+ * ev_job_thumbnail_set_output_format:
+ * @job: a #EvJobThumbnail
+ * @format: a #EvJobThumbnailFormat
+ *
+ * Set the desired output format for the generated thumbnail
+ *
+ * Since: 3.14
+ */
+void
+ev_job_thumbnail_set_output_format (EvJobThumbnail      *job,
+                                    EvJobThumbnailFormat format)
+{
+        job->format = format;
+}
+
 /* EvJobFonts */
 static void
 ev_job_fonts_init (EvJobFonts *job)
